@@ -53,52 +53,52 @@ setMethodS3("plotDensity", "AffymetrixCelFile", function(this, subset=NULL, type
   # Argument 'xlab':
   if (is.null(xlab)) {
     if (log) {
-      xlab <- expression(log[2](y));
+      xlab <- expression(log[2](y))
     } else {
-      xlab <- expression(y);
+      xlab <- expression(y)
     }
   }
 
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Identify the subset of probes to be updated
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  cdf <- getCdf(this);
-  verbose && enter(verbose, "Identifying subset of probes");
+  cdf <- getCdf(this)
+  verbose && enter(verbose, "Identifying subset of probes")
   suppressWarnings({
     subset <- identifyCells(cdf, indices=subset, types=types,
-                                                    verbose=less(verbose));
+                                                    verbose=less(verbose))
   })
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Plot density
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  verbose && enter(verbose, "Plotting the density");
-  verbose && cat(verbose, "Array: ", getName(this));
+  verbose && enter(verbose, "Plotting the density")
+  verbose && cat(verbose, "Array: ", getName(this))
   suppressWarnings({
-    verbose && enter(verbose, "Loading probe intensities");
-    y <- getData(this, indices=subset, fields="intensities");
-    y <- y$intensities;
-    verbose && exit(verbose);
+    verbose && enter(verbose, "Loading probe intensities")
+    y <- getData(this, indices=subset, fields="intensities")
+    y <- y$intensities
+    verbose && exit(verbose)
     if (log) {
-      verbose && cat(verbose, "Taking the logarithm (base 2)");
-      y <- log(y, base=2);
+      verbose && cat(verbose, "Taking the logarithm (base 2)")
+      y <- log(y, base=2)
     }
-    verbose && cat(verbose, "Plotting");
-    plotDensity(y, xlim=xlim, xlab=xlab, ylab=ylab, ...);
+    verbose && cat(verbose, "Plotting")
+    plotDensity(y, xlim=xlim, xlab=xlab, ylab=ylab, ...)
   })
 
   if (annotate) {
-    stextChipType(getChipType(this));
-    stextLabels(this);
-    stextSize(this, size=length(y));
+    stextChipType(getChipType(this))
+    stextLabels(this)
+    stextSize(this, size=length(y))
   }
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 })
 
 
@@ -108,13 +108,13 @@ setMethodS3("getAm", "AffymetrixCelFile", function(this, reference, indices=NULL
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Arguments 'reference':
-  reference <- Arguments$getInstanceOf(reference, "AffymetrixCelFile");
+  reference <- Arguments$getInstanceOf(reference, "AffymetrixCelFile")
 
   # Argument 'indices':
-  nbrOfCells <- nbrOfCells(this);
+  nbrOfCells <- nbrOfCells(this)
   if (is.null(indices)) {
   } else {
-    indices <- Arguments$getIndices(indices, max=nbrOfCells);
+    indices <- Arguments$getIndices(indices, max=nbrOfCells)
   }
 
 
@@ -124,7 +124,7 @@ setMethodS3("getAm", "AffymetrixCelFile", function(this, reference, indices=NULL
   # Check if the two CEL files are compatible
   if (nbrOfCells != nbrOfCells(reference)) {
     throw("This and the 'reference' CEL file have different number of cells: ",
-                                   nbrOfCells, " != ", nbrOfCells(reference));
+                                   nbrOfCells, " != ", nbrOfCells(reference))
   }
 
 
@@ -132,66 +132,66 @@ setMethodS3("getAm", "AffymetrixCelFile", function(this, reference, indices=NULL
   # Get signals
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Get the signals for this channel
-  y1 <- getData(this, indices=indices, fields="intensities")[,1];
+  y1 <- getData(this, indices=indices, fields="intensities")[,1]
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Offset signals?
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  offset <- this$offset;
+  offset <- this$offset
   if (is.null(offset))
-    offset <- 0;
+    offset <- 0
   if (offset != 0)
-    cat("Offset: ", offset, "\n", sep="");
+    cat("Offset: ", offset, "\n", sep="")
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Remove signals that are zero?
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (!zeros) {
-    keep <- which(y1 != 0);
-    y1 <- y1[keep];
+    keep <- which(y1 != 0)
+    y1 <- y1[keep]
   } else {
-    keep <- seq_along(y1);
+    keep <- seq_along(y1)
   }
-  y1 <- y1 + offset;
-  y1 <- log(y1, base=2);
+  y1 <- y1 + offset
+  y1 <- log(y1, base=2)
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Get reference signals
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (length(y1) == 0) {
-    y2 <- y1;
+    y2 <- y1
   } else {
     # Get the signals for the reference channel
     if (is.null(indices)) {
-      indices <- keep;
+      indices <- keep
     } else {
-      indices <- indices[keep];
+      indices <- indices[keep]
     }
-    y2 <- getData(reference, indices=indices, fields="intensities")[,1];
-    y2 <- y2 + offset;
-    y2 <- log(y2, base=2);
+    y2 <- getData(reference, indices=indices, fields="intensities")[,1]
+    y2 <- y2 + offset
+    y2 <- log(y2, base=2)
   }
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Return (A,M)
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  am <- matrix(c((y1+y2)/2, y1-y2), ncol=2);
-  colnames(am) <- c("A", "M");
+  am <- matrix(c((y1+y2)/2, y1-y2), ncol=2)
+  colnames(am) <- c("A", "M")
 
-  am;
+  am
 })
 
 
 
 setMethodS3("annotateMvsA", "AffymetrixCelFile", function(this, reference, ..., what="M") {
   if (identical(what, "M")) {
-    abline(h=0, lty=1, col="blue");
+    abline(h=0, lty=1, col="blue")
   }
-  stextChipType(getChipType(this));
-  stextLabels(this, others=reference);
+  stextChipType(getChipType(this))
+  stextLabels(this, others=reference)
 }, private=TRUE)
 
 
@@ -234,14 +234,14 @@ setMethodS3("annotateMvsA", "AffymetrixCelFile", function(this, reference, ...,
 # }
 #*/###########################################################################
 setMethodS3("plotMvsA", "AffymetrixCelFile", function(this, reference, indices=NULL, pch=176, xlim=c(0,16), ylim=c(-1,1)*diff(xlim), xlab=expression(A==1/2%*%log[2](y[1]*y[2])), ylab=expression(M==log[2](y[1]/y[2])), ..., annotate=TRUE) {
-  ma <- getAm(this, reference, indices=indices);
-  plot(ma, pch=pch, xlab=xlab, ylab=ylab, xlim=xlim, ylim=ylim, ...);
+  ma <- getAm(this, reference, indices=indices)
+  plot(ma, pch=pch, xlab=xlab, ylab=ylab, xlim=xlim, ylim=ylim, ...)
   if (annotate) {
-    annotateMvsA(this, reference);
-    stextSize(this, size=nrow(ma));
+    annotateMvsA(this, reference)
+    stextSize(this, size=nrow(ma))
   }
-  this$lastPlotData <- ma;
-  invisible(ma);
+  this$lastPlotData <- ma
+  invisible(ma)
 })
 
 
@@ -283,14 +283,14 @@ setMethodS3("plotMvsA", "AffymetrixCelFile", function(this, reference, indices=N
 # }
 #*/###########################################################################
 setMethodS3("smoothScatterMvsA", "AffymetrixCelFile", function(this, reference, indices=NULL, pch=176, xlim=c(0,16), ylim=c(-1,1)*diff(xlim), xlab=expression(A==1/2%*%log[2](y[1]*y[2])), ylab=expression(M==log[2](y[1]/y[2])), ..., annotate=TRUE) {
-  ma <- getAm(this, reference, indices=indices);
-  smoothScatter(ma, pch=pch, xlab=xlab, ylab=ylab, xlim=xlim, ylim=ylim, ...);
+  ma <- getAm(this, reference, indices=indices)
+  smoothScatter(ma, pch=pch, xlab=xlab, ylab=ylab, xlim=xlim, ylim=ylim, ...)
   if (annotate) {
-    annotateMvsA(this, reference);
-    stextSize(this, size=nrow(ma));
+    annotateMvsA(this, reference)
+    stextSize(this, size=nrow(ma))
   }
-  this$lastPlotData <- ma;
-  invisible(ma);
+  this$lastPlotData <- ma
+  invisible(ma)
 })
 
 
@@ -335,40 +335,40 @@ setMethodS3("smoothScatterMvsA", "AffymetrixCelFile", function(this, reference,
 #*/###########################################################################
 setMethodS3("plotMvsX", "AffymetrixCelFile", function(this, reference, x, indices=NULL, pch=176, ylim=c(-1,1)*2, ylab=NULL, ..., what=c("M", "A"), add=FALSE, annotate=!add) {
   # Argument 'what':
-  what <- match.arg(what);
+  what <- match.arg(what)
 
   # Get the log-ratios
-  ma <- getAm(this, reference, indices=indices, zeros=TRUE);
-  nobs <- nrow(ma);
+  ma <- getAm(this, reference, indices=indices, zeros=TRUE)
+  nobs <- nrow(ma)
   if (nobs == 0)
-    throw("Cannot plot M vs X because there is not non-zero data.");
+    throw("Cannot plot M vs X because there is not non-zero data.")
 
   if (nobs != length(x)) {
-    throw("The number of log-ratios does not match the number of elements in argument 'x': ", length(nobs), " != ", length(x));
+    throw("The number of log-ratios does not match the number of elements in argument 'x': ", length(nobs), " != ", length(x))
   }
 
   if (what == "M") {
     ylab <- expression(M==log[2](y1/y2))
   } else {
-    ma <- ma[,2:1];
+    ma <- ma[,2:1]
     ylab <- expression(A==1/2%*%log[2](y1*y2))
   }
 
   if (add) {
-    points(x, ma[,1], pch=pch, ...);
+    points(x, ma[,1], pch=pch, ...)
   } else {
-    plot(x, ma[,1], pch=pch, ylim=ylim, ylab=ylab, ...);
+    plot(x, ma[,1], pch=pch, ylim=ylim, ylab=ylab, ...)
     if (annotate) {
-      annotateMvsA(this, reference, what=what);
-      stextSize(this, size=length(x));
+      annotateMvsA(this, reference, what=what)
+      stextSize(this, size=length(x))
     }
   }
 
   # The first two columns should always be the data plotted
-  ma <- cbind(x=x, ma);
+  ma <- cbind(x=x, ma)
 
-  this$lastPlotData <- ma;
-  invisible(ma);
+  this$lastPlotData <- ma
+  invisible(ma)
 })
 
 
@@ -376,11 +376,11 @@ setMethodS3("plotMvsX", "AffymetrixCelFile", function(this, reference, x, indice
 
 
 setMethodS3("highlight", "AffymetrixCelFile", function(this, indices=NULL, ...) {
-  data <- this$lastPlotData;
+  data <- this$lastPlotData
   if (!is.null(indices))
-    data <- data[indices,,drop=FALSE];
-  points(data[,1:2], ...);
-  invisible(data);
+    data <- data[indices,,drop=FALSE]
+  points(data[,1:2], ...)
+  invisible(data)
 }, protected=TRUE)
 
 
@@ -428,45 +428,45 @@ setMethodS3("image270", "AffymetrixCelFile", function(this, xrange=c(0,Inf), yra
   }
 
   # Argument 'field':
-  field <- match.arg(field);
+  field <- match.arg(field)
 
   suppressWarnings({
     y <- readRawDataRectangle(this, xrange=xrange, yrange=yrange,
-                                              fields=field, ..., drop=TRUE);
+                                              fields=field, ..., drop=TRUE)
   })
 
   # if only PM locations have signal, add a fake row
 
-  nr <- nrow(y);
+  nr <- nrow(y)
   if (interleaved) {
-    idxEven <- which((1:nr) %% 2 == 0);
-    y[idxEven-1,] <- y[idxEven,];
+    idxEven <- which((1:nr) %% 2 == 0)
+    y[idxEven-1,] <- y[idxEven,]
   }
 
   suppressWarnings({
     if (takeLog) {
-      image(log2(rotate270(y)), col=col, ..., axes=FALSE, main=main);
+      image(log2(rotate270(y)), col=col, ..., axes=FALSE, main=main)
     } else {
-      image(rotate270(y), col=col, ..., axes=FALSE, main=main);
+      image(rotate270(y), col=col, ..., axes=FALSE, main=main)
     }
   })
 
   if (is.null(xrange) || xrange[2] == Inf)
-    xrange <- c(0,ncol(y)-1);
+    xrange <- c(0,ncol(y)-1)
   if (is.null(yrange) || yrange[2] == Inf)
-    yrange <- c(0,nrow(y)-1);
+    yrange <- c(0,nrow(y)-1)
 
-  cdf <- getCdf(this);
-  dim <- paste(getDimension(cdf), collapse="x");
-  label <- sprintf("Chip type: %s [%s]", getChipType(this), dim);
+  cdf <- getCdf(this)
+  dim <- paste(getDimension(cdf), collapse="x")
+  label <- sprintf("Chip type: %s [%s]", getChipType(this), dim)
   text(x=0, y=0, labels=label, adj=c(0,1.2), cex=0.8, xpd=TRUE)
-  label <- sprintf("(%d,%d)", as.integer(xrange[1]), as.integer(yrange[1]));
+  label <- sprintf("(%d,%d)", as.integer(xrange[1]), as.integer(yrange[1]))
   text(x=0, y=1, labels=label, adj=c(0,-0.7), cex=0.8, xpd=TRUE)
-  label <- sprintf("(%d,%d)", as.integer(xrange[2]), as.integer(yrange[2]));
+  label <- sprintf("(%d,%d)", as.integer(xrange[2]), as.integer(yrange[2]))
   text(x=1, y=0, labels=label, adj=c(1,1.2), cex=0.8, xpd=TRUE)
 
   # Return the plotted data.
-  invisible(y);
+  invisible(y)
 })
 
 
@@ -524,24 +524,24 @@ setMethodS3("getImage", "AffymetrixCelFile", function(this, other=NULL, transfor
   readRectangleByField <- function(this, other=NULL, xrange, yrange, ...) {
     suppressWarnings({
       y <- readRawDataRectangle(this, xrange=xrange, yrange=yrange,
-                                               fields=field, ..., drop=TRUE);
-    });
+                                               fields=field, ..., drop=TRUE)
+    })
 
     if (is.null(other)) {
     } else {
       if (inherits(other, "AffymetrixCelFile")) {
         suppressWarnings({
           yR <- readRawDataRectangle(other, xrange=xrange, yrange=yrange,
-                                               fields=field, ..., drop=TRUE);
-        });
+                                               fields=field, ..., drop=TRUE)
+        })
       } else {
-        yR <- other;
+        yR <- other
       }
 
-      y <- y/yR;
+      y <- y/yR
     }
 
-    y;
+    y
   } # readRectangleByField()
 
 
@@ -551,58 +551,58 @@ setMethodS3("getImage", "AffymetrixCelFile", function(this, other=NULL, transfor
   # Argument 'other':
   if (!is.null(other)) {
     if (inherits(other, "AffymetrixCelFile")) {
-      hdr1 <- getHeader(this);
-      hdr2 <- getHeader(other);
-      fields <- c("rows", "cols");
+      hdr1 <- getHeader(this)
+      hdr2 <- getHeader(other)
+      fields <- c("rows", "cols")
       if (!identical(hdr1[fields], hdr2[fields])) {
-        throw("Argument 'other' contains an ", class(other)[1], " with a dimension not compatible with the main ", class(this)[1], "");
+        throw("Argument 'other' contains an ", class(other)[1], " with a dimension not compatible with the main ", class(this)[1], "")
       }
     } else {
-      throw("Argument 'other' is of an unknown class: ", other);
+      throw("Argument 'other' is of an unknown class: ", other)
     }
   }
 
   # Argument 'field':
-  field <- match.arg(field);
+  field <- match.arg(field)
 
   # Argument 'zoom':
-  zoom <- Arguments$getDouble(zoom, range=c(0,Inf));
+  zoom <- Arguments$getDouble(zoom, range=c(0,Inf))
 
   # Argument 'readRectFcn':
   if (is.null(readRectFcn)) {
-    readRectFcn <- readRectangleByField;
+    readRectFcn <- readRectangleByField
   } else if (!is.function(readRectFcn)) {
-    throw("Argument 'readRectFcn' is not a function: ", readRectFcn);
+    throw("Argument 'readRectFcn' is not a function: ", readRectFcn)
   }
 
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Read data
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  verbose && enter(verbose, "Getting CEL image");
+  verbose && enter(verbose, "Getting CEL image")
 
-  verbose && enter(verbose, "Reading CEL image");
-  y <- readRectFcn(this, other=other, xrange=xrange, yrange=yrange, ...);
-  verbose && str(verbose, y);
-  verbose && summary(verbose, as.vector(y[is.finite(y) & (y != 0)]));
+  verbose && enter(verbose, "Reading CEL image")
+  y <- readRectFcn(this, other=other, xrange=xrange, yrange=yrange, ...)
+  verbose && str(verbose, y)
+  verbose && summary(verbose, as.vector(y[is.finite(y) & (y != 0)]))
   verbose && printf(verbose, "RAM: %s\n", hsize(object.size(y), digits = 2L, standard = "IEC"))
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
-  verbose && enter(verbose, "Creating Image");
+  verbose && enter(verbose, "Creating Image")
   img <- getImage(y, transforms=transforms, scale=zoom, lim=zrange, ...,
-                                                   verbose=less(verbose, 1));
-  verbose && print(verbose, img);
-  verbose && exit(verbose);
+                                                   verbose=less(verbose, 1))
+  verbose && print(verbose, img)
+  verbose && exit(verbose)
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
   # Return the 'field'
-  attr(img, "field") <- field;
+  attr(img, "field") <- field
 
-  img;
+  img
 })
 
 
@@ -636,12 +636,12 @@ setMethodS3("getImage", "AffymetrixCelFile", function(this, other=NULL, transfor
 #*/###########################################################################
 setMethodS3("plotImage", "AffymetrixCelFile", function(this, ...) {
   # Get the image
-  img <- getImage(this, ...);
+  img <- getImage(this, ...)
 
   # Display image
   display(img);  # Using display() for Image of aroma.core
 
-  invisible(img);
+  invisible(img)
 })
 
 
@@ -697,148 +697,75 @@ setMethodS3("plotImage", "AffymetrixCelFile", function(this, ...) {
 setMethodS3("writeImage", "AffymetrixCelFile", function(this, filename=NULL, fullname=NULL, tags=c("*", "sqrt", "gray"), imgFormat="png", path=NULL,  field=c("intensities", "stdvs", "pixels"), ..., skip=TRUE, verbose=FALSE) {
   # Argument 'path':
   if (is.null(path)) {
-    rootPath <- "reports";
+    rootPath <- "reports"
 
     # Infer the data set name and the tags from the path
-    path <- getPath(this);
+    path <- getPath(this)
     parent <- getParent(path); # chip type
     parent <- getParent(path); # data set
-    parts <- unlist(strsplit(basename(parent), split=","));
-    dataSet <- parts[1];
-    dataSetTags <- parts[-1];
+    parts <- unlist(strsplit(basename(parent), split=","))
+    dataSet <- parts[1]
+    dataSetTags <- parts[-1]
     if (length(dataSetTags) == 0) {
-      dataSetTags <- "raw";
+      dataSetTags <- "raw"
     } else {
-      dataSetTags <- paste(dataSetTags, collapse=",");
+      dataSetTags <- paste(dataSetTags, collapse=",")
     }
 
     # chip type
-    chipType <- getChipType(this, fullname=FALSE);
+    chipType <- getChipType(this, fullname=FALSE)
 
     # image set
-    set <- "spatial";
+    set <- "spatial"
 
-    path <- filePath(rootPath, dataSet, dataSetTags, chipType, set);
+    path <- filePath(rootPath, dataSet, dataSetTags, chipType, set)
   }
-  path <- Arguments$getWritablePath(path);
+  path <- Arguments$getWritablePath(path)
 
   # Argument 'tags':
-  tags <- Arguments$getCharacters(tags);
+  tags <- Arguments$getCharacters(tags)
 
   # Argument 'filename':
 
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
 
 
   # Update asterisk tags?
   if ("*" %in% tags) {
-    idx <- match("*", tags);
-    tags[idx] <- field;
-    tags <- locallyUnique(tags);
+    idx <- match("*", tags)
+    tags[idx] <- field
+    tags <- locallyUnique(tags)
   }
 
-  verbose && enter(verbose, "Writing CEL image to file");
+  verbose && enter(verbose, "Writing CEL image to file")
 
   # Generate the pathname
   if (is.null(fullname)) {
-    fullname <- getFullName(this);
+    fullname <- getFullName(this)
   }
-  fullname <- paste(c(fullname, tags), collapse=",");
+  fullname <- paste(c(fullname, tags), collapse=",")
   if (is.null(filename)) {
-    filename <- sprintf("%s.%s", fullname, imgFormat);
+    filename <- sprintf("%s.%s", fullname, imgFormat)
   }
-  pathname <- Arguments$getWritablePathname(filename, path=path);
-  verbose && cat(verbose, "Pathname: ", pathname);
+  pathname <- Arguments$getWritablePathname(filename, path=path)
+  verbose && cat(verbose, "Pathname: ", pathname)
 
   if (!skip || !isFile(pathname)) {
-    verbose && enter(verbose, "Getting image");
-    img <- getImage(this, ..., verbose=less(verbose));
+    verbose && enter(verbose, "Getting image")
+    img <- getImage(this, ..., verbose=less(verbose))
 
-    verbose && cat(verbose, "Image object:");
-    verbose && print(verbose, img);
-    verbose && exit(verbose);
+    verbose && cat(verbose, "Image object:")
+    verbose && print(verbose, img)
+    verbose && exit(verbose)
 
-    verbose && enter(verbose, "Writing image");
-    writeImage(img, file=pathname);
-    verbose && exit(verbose);
+    verbose && enter(verbose, "Writing image")
+    writeImage(img, file=pathname)
+    verbose && exit(verbose)
   }
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
   # Return pathname
-  pathname;
+  pathname
 })
-
-
-
-############################################################################
-# HISTORY:
-# 2012-11-14
-# o CLEANUP: writeImage() for AffymetrixCelFile no longer supports
-#   sample name aliases.
-# 2011-01-30
-# o CLEAN UP: getImage(), plotImage() and writeImage() for AffymetrixCelFile
-#   no longer depend explicitly on EBImage but instead calls aroma.core's
-#   getImage(), display(), and writeImage(), respectively.  The latter
-#   methods depend on EBimage for now.
-# 2009-09-04
-# o Now smoothScatter() is loaded via aroma.core.
-# 2009-09-17
-# o Now argument 'subset' of plotDensity() of AffymetrixCelFile defaults
-#   to NULL (all probes).  Before it was 1/2 (a fraction).
-# 2008-03-14
-# o Added argument 'readRectFcn' to getImage() allowing one to read data
-#   in different ways, e.g. by also read a reference array and return
-#   log-ratios.
-# 2007-09-17
-# o Added write.image()/writeImage() caller to avoid recent EBImage
-#   warnings about write.image() being deprecated.
-# 2007-06-11
-# o Explicit calls to geneplotter::smoothScatter() & EBImage::write.image().
-# 2007-06-07
-# o BUG FIX: When argument 'transforms' to getImage() of AffymetrixCelFile
-#   wasn't a list, then "Error: argument "transform" is missing, with no
-#   default" was thrown.  Thanks Karen Vranizan, UC Berkeley for reporting
-#   this problem.
-# 2007-03-20
-# o Now writeImage() uses the file alias as the name if it exists.
-# 2007-03-19
-# o Now getImage() and writeSpatial() accepts a list of transform functions.
-# 2007-03-15
-# o Argument '...' to plotDensity() of AffymetrixCelFile and
-#   AffymetrixCelSet are no longer passed to identifyCells().
-# 2007-02-16
-# o Increased the threshold to detect empty rows/columns in getImage().
-# 2007-02-06
-# o Now writeImage() writes image files to
-#   <rootPath>/<dataSet>/<tags>/<chipType>/<set>/.
-# 2007-02-03
-# o plotDensity() now make sure aroma.light is loaded.
-# 2007-01-30
-# o Image functions tested with EBImage v1.9.23 on WinXP.
-# o Changed the default transform to sqrt().
-# o Added 'tags' to writeImage().
-# o Renamed plotImageToFile() to writeImage().
-# 2007-01-12 /KS
-# o TODO? Image methods needed for AffymetrixCelSets?  Or just use lapply?
-# o TODO: Annotation of plots generated by EBImage. (are tags enough? /HB)
-# o Added getImage(), plotImage() and plotImageToFile(), which use
-#   EBImage functionality.
-# o Moved image270() and writeSpatial() from AffymetrixCelFile.R.
-# 2006-09-26
-# o Renamed calcMvsA() to getAm().
-# 2006-09-15
-# o Added more Rdoc comments.
-# o Readded plotDensity().
-# o Added stextSize() to annotate with "n=1034".
-# 2006-08-27
-# o Added plotMvsX() and plotMvsPosition().
-# o Added calcMvsA(), plotMvsA(), and smoothScatterMvsA().
-# 2006-07-27
-# o Added argument 'verbose' to plotDensity().
-# 2006-05-29
-# o Added Rdoc comments.
-# 2006-05-16
-# o Created.
-############################################################################
