@@ -35,20 +35,20 @@ setConstructorS3("GcContentNormalization", function(dataSet=NULL, ..., targetFun
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'dataSet':
   if (!is.null(dataSet)) {
-    dataSet <- Arguments$getInstanceOf(dataSet, "CnChipEffectSet");
+    dataSet <- Arguments$getInstanceOf(dataSet, "CnChipEffectSet")
 
     if (dataSet$combineAlleles != TRUE) {
-      throw("Currently only total copy-number chip effects can be normalized, i.e. 'combineAlleles' must be TRUE");
+      throw("Currently only total copy-number chip effects can be normalized, i.e. 'combineAlleles' must be TRUE")
     }
 
 #    if (dataSet$mergeStrands != TRUE) {
-#      throw("Currently only non-strands specific copy-number chip effects can be normalized, i.e. 'mergeStrands' must be TRUE");
+#      throw("Currently only non-strands specific copy-number chip effects can be normalized, i.e. 'mergeStrands' must be TRUE")
 #    }
   }
 
   if (!is.null(targetFunction)) {
     if (!is.function(targetFunction)) {
-      throw("Argument 'targetFunction' is not a function: ", class(targetFunction)[1]);
+      throw("Argument 'targetFunction' is not a function: ", class(targetFunction)[1])
     }
   }
 
@@ -62,43 +62,43 @@ setConstructorS3("GcContentNormalization", function(dataSet=NULL, ..., targetFun
 
 setMethodS3("getParameters", "GcContentNormalization", function(this, ...) {
   # Get parameters from super class
-  params <- NextMethod("getParameters");
+  params <- NextMethod("getParameters")
 
   # Get parameters of this class
   params2 <- list(
     subsetToFit = this$.subsetToFit,
     .targetFunction = this$.targetFunction
-  );
+  )
 
   # Append the two sets
-  params <- c(params, params2);
+  params <- c(params, params2)
 
-  params;
+  params
 }, protected=TRUE)
 
 
 setMethodS3("getCdf", "GcContentNormalization", function(this, ...) {
-  inputDataSet <- getInputDataSet(this);
-  getCdf(inputDataSet);
+  inputDataSet <- getInputDataSet(this)
+  getCdf(inputDataSet)
 })
 
 
 setMethodS3("getOutputDataSet00", "GcContentNormalization", function(this, ...) {
-  res <- NextMethod("getOutputDataSet");
+  res <- NextMethod("getOutputDataSet")
 
   # Carry over parameters too.  AD HOC for now. /HB 2007-01-07
   if (inherits(res, "SnpChipEffectSet")) {
-    ces <- getInputDataSet(this);
-    res$mergeStrands <- ces$mergeStrands;
+    ces <- getInputDataSet(this)
+    res$mergeStrands <- ces$mergeStrands
     if (inherits(res, "CnChipEffectSet")) {
-      res$combineAlleles <- ces$combineAlleles;
+      res$combineAlleles <- ces$combineAlleles
     }
   }
 
   # Let the set update itself
-  update2(res);
+  update2(res)
 
-  res;
+  res
 }, protected=TRUE)
 
 
@@ -107,101 +107,101 @@ setMethodS3("getGcContent", "GcContentNormalization", function(this, units=NULL,
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
   if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
+    pushState(verbose)
+    on.exit(popState(verbose))
   }
 
   # Argument 'units':
-  cdf <- getCdf(this);
-  units <- Arguments$getIndices(units, max=nbrOfUnits);
+  cdf <- getCdf(this)
+  units <- Arguments$getIndices(units, max=nbrOfUnits)
 
 
-  verbose && enter(verbose, "Retrieving GC content");
-  chipType <- getChipType(cdf);
-  chipType <- gsub(",monocell", "", chipType);
-  verbose && cat(verbose, "Chip type: ", chipType);
-  verbose && cat(verbose, "Units:");
-  verbose && str(verbose, units);
+  verbose && enter(verbose, "Retrieving GC content")
+  chipType <- getChipType(cdf)
+  chipType <- gsub(",monocell", "", chipType)
+  verbose && cat(verbose, "Chip type: ", chipType)
+  verbose && cat(verbose, "Units:")
+  verbose && str(verbose, units)
 
-  gcContents <- NULL;
+  gcContents <- NULL
   # Try 1: Use an unit GC content (UGC) file
   tryCatch({
-    ugc <- AromaUgcFile$byChipType(chipType);
-    gcContents <- ugc[units,1,drop=TRUE];
+    ugc <- AromaUgcFile$byChipType(chipType)
+    gcContents <- ugc[units,1,drop=TRUE]
   }, error = function(ex) {
   })
 
   # Try 2: Use a TSV file (deprecated; kept for backward compatibility)
   if (is.null(gcContents)) {
     tryCatch({
-      chipTypeS <- gsub(",.*", "", chipType);
-      tsv <- AffymetrixTsvFile$byChipType(chipTypeS);
-      gcContents <- getGc(tsv, units=units);
+      chipTypeS <- gsub(",.*", "", chipType)
+      tsv <- AffymetrixTsvFile$byChipType(chipTypeS)
+      gcContents <- getGc(tsv, units=units)
     }, error = function(ex) {
     })
   }
 
   if (is.null(gcContents)) {
-    throw("Failed to retrieve GC content information. No GC-content annotation file found: ", chipType);
+    throw("Failed to retrieve GC content information. No GC-content annotation file found: ", chipType)
   }
 
-  verbose && cat(verbose, "GC contents:");
-  verbose && str(verbose, gcContents);
-  verbose && exit(verbose);
+  verbose && cat(verbose, "GC contents:")
+  verbose && str(verbose, gcContents)
+  verbose && exit(verbose)
 
-  gcContents;
-}, protected=TRUE);
+  gcContents
+}, protected=TRUE)
 
 
 setMethodS3("getSubsetToFit", "GcContentNormalization", function(this, force=FALSE, ...) {
   # Cached?
-  units <- this$.units;
+  units <- this$.units
   if (!is.null(units) && !force)
-    return(units);
+    return(units)
 
   # Identify all SNP & CN units
-  cdf <- getCdf(this);
-  types <- getUnitTypes(cdf, ...);
-  units <- which(types == 2 | types == 5);
+  cdf <- getCdf(this)
+  types <- getUnitTypes(cdf, ...)
+  units <- which(types == 2 | types == 5)
 
   # Keep only those for which we have GC contents information
-  gcContents <- getGcContent(this, units=units, ...);
+  gcContents <- getGcContent(this, units=units, ...)
 
-  keep <- is.finite(gcContents);
-  units <- units[keep];
+  keep <- is.finite(gcContents)
+  units <- units[keep]
 
   # Fit to a subset of the units?
-  subsetToFit <- this$.subsetToFit;
+  subsetToFit <- this$.subsetToFit
   if (!is.null(subsetToFit)) {
     # A fraction subset?
     if (length(subsetToFit) == 1 && 0 < subsetToFit && subsetToFit < 1) {
-      keep <- seq(from=1, to=length(units), length=subsetToFit*length(units));
+      keep <- seq(from=1, to=length(units), length=subsetToFit*length(units))
     } else {
-      keep <- which(units %in% subsetToFit);
+      keep <- which(units %in% subsetToFit)
     }
 
     # Make sure to keep data points at the tails too
-    keep <- c(keep, which.min(gcContents), which.max(gcContents));
-    keep <- unique(keep);
+    keep <- c(keep, which.min(gcContents), which.max(gcContents))
+    keep <- unique(keep)
 
     # Now filter
-    units <- units[keep];
+    units <- units[keep]
     # Not needed anymore
-    keep <- NULL;
+    keep <- NULL
   }
 
   # Sort units
-  units <- sort(units);
+  units <- sort(units)
 
   # Assert correctness
-  units <- Arguments$getIndices(units, max=nbrOfUnits(cdf));
+  units <- Arguments$getIndices(units, max=nbrOfUnits(cdf))
 
   # Cache
-  this$.units <- units;
+  this$.units <- units
 
-  units;
+  units
 }, private=TRUE)
 
 
@@ -211,77 +211,77 @@ setMethodS3("getTargetFunction", "GcContentNormalization", function(this, ..., f
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
   if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
+    pushState(verbose)
+    on.exit(popState(verbose))
   }
 
 
-  fcn <- this$.targetFunction;
+  fcn <- this$.targetFunction
   if (is.null(fcn) || force) {
-    verbose && enter(verbose, "Estimating target prediction function");
+    verbose && enter(verbose, "Estimating target prediction function")
 
     # Get the GC-content annotation data
-    gcContents <- getGcContent(this, verbose=less(verbose));
+    gcContents <- getGcContent(this, verbose=less(verbose))
 
     # Get target set
-    ces <- getInputDataSet(this);
-    verbose && enter(verbose, "Get average signal across arrays");
-    ceR <- getAverageFile(ces, force=force, verbose=less(verbose));
-    verbose && exit(verbose);
+    ces <- getInputDataSet(this)
+    verbose && enter(verbose, "Get average signal across arrays")
+    ceR <- getAverageFile(ces, force=force, verbose=less(verbose))
+    verbose && exit(verbose)
 
     # Garbage collect
-    gc <- gc();
-    verbose && print(verbose, gc);
+    gc <- gc()
+    verbose && print(verbose, gc)
 
     # Get units to fit
-    units <- getSubsetToFit(this);
+    units <- getSubsetToFit(this)
 
     # Get target log2 signals for SNPs
-    data <- getDataFlat(ceR, units=units, fields="theta", verbose=less(verbose));
-    units <- data[,"unit"];
-    verbose && cat(verbose, "Units:");
-    verbose && str(verbose, units);
+    data <- getDataFlat(ceR, units=units, fields="theta", verbose=less(verbose))
+    units <- data[,"unit"]
+    verbose && cat(verbose, "Units:")
+    verbose && str(verbose, units)
 
-    yR <- data[,"theta"];
+    yR <- data[,"theta"]
     # Not needed anymore
     data <- NULL; # Not needed anymore
-    yR <- log2(yR);
-    verbose && cat(verbose, "Signals:");
-    verbose && str(verbose, yR);
+    yR <- log2(yR)
+    verbose && cat(verbose, "Signals:")
+    verbose && str(verbose, yR)
 
     # Get GC contents for these units
-    gcContents <- gcContents[units];
-    verbose && cat(verbose, "GC content:");
-    verbose && str(verbose, gcContents);
+    gcContents <- gcContents[units]
+    verbose && cat(verbose, "GC content:")
+    verbose && str(verbose, gcContents)
 
     # Fit lowess function
-    verbose && enter(verbose, "Fitting target prediction function");
-    ok <- (is.finite(gcContents) & is.finite(yR));
-    fit <- lowess(gcContents[ok], yR[ok]);
-    class(fit) <- "lowess";
+    verbose && enter(verbose, "Fitting target prediction function")
+    ok <- (is.finite(gcContents) & is.finite(yR))
+    fit <- lowess(gcContents[ok], yR[ok])
+    class(fit) <- "lowess"
 
     # Remove as many promises as possible
     # Not needed anymore
-    fcn <- ces <- ceR <- units <- gc <- yR <- ok <- NULL;
+    fcn <- ces <- ceR <- units <- gc <- yR <- ok <- NULL
 
     # Create target prediction function
     fcn <- function(x, ...) {
       predict(fit, x, ...);  # Dispatched predict.lowess().
     }
-    verbose && exit(verbose);
+    verbose && exit(verbose)
 
     # Garbage collect
-    gc <- gc();
-    verbose && print(verbose, gc);
+    gc <- gc()
+    verbose && print(verbose, gc)
 
-    verbose && exit(verbose);
+    verbose && exit(verbose)
 
-    this$.targetFunction <- fcn;
+    this$.targetFunction <- fcn
   }
 
-  fcn;
+  fcn
 }, private=TRUE)
 
 
@@ -317,22 +317,22 @@ setMethodS3("process", "GcContentNormalization", function(this, ..., force=FALSE
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
   if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
+    pushState(verbose)
+    on.exit(popState(verbose))
   }
 
-  verbose && enter(verbose, "Normalizing set for PCR fragment-length effects");
+  verbose && enter(verbose, "Normalizing set for PCR fragment-length effects")
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Already done?
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (!force && isDone(this)) {
-    verbose && cat(verbose, "Already normalized");
-    verbose && exit(verbose);
-    outputSet <- getOutputDataSet(this);
-    return(invisible(outputSet));
+    verbose && cat(verbose, "Already normalized")
+    verbose && exit(verbose)
+    outputSet <- getOutputDataSet(this)
+    return(invisible(outputSet))
   }
 
 
@@ -340,162 +340,147 @@ setMethodS3("process", "GcContentNormalization", function(this, ..., force=FALSE
   # Setup
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Get input data set
-  ces <- getInputDataSet(this);
+  ces <- getInputDataSet(this)
 
   # Get SNP (& CN) units
-  cdf <- getCdf(ces);
-#  subsetToUpdate <- indexOf(cdf, "SNP_");
-  types <- getUnitTypes(cdf, ...);
-  subsetToUpdate <- which(types == 2 | types == 5);
+  cdf <- getCdf(ces)
+#  subsetToUpdate <- indexOf(cdf, "SNP_")
+  types <- getUnitTypes(cdf, ...)
+  subsetToUpdate <- which(types == 2 | types == 5)
 
-  verbose && enter(verbose, "Identifying the subset used to fit normalization function");
+  verbose && enter(verbose, "Identifying the subset used to fit normalization function")
   # Get subset to fit
-  subsetToFit <- getSubsetToFit(this, verbose=less(verbose));
-  verbose && str(verbose, subsetToFit);
-  verbose && exit(verbose);
+  subsetToFit <- getSubsetToFit(this, verbose=less(verbose))
+  verbose && str(verbose, subsetToFit)
+  verbose && exit(verbose)
 
   # Get (and create) the output path
-  path <- getPath(this);
+  path <- getPath(this)
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Normalize each array
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  gcContents <- NULL;
-  targetFcn <- NULL;
-  map <- NULL;
-  nbrOfArrays <- length(ces);
-  res <- vector("list", nbrOfArrays);
+  gcContents <- NULL
+  targetFcn <- NULL
+  map <- NULL
+  nbrOfArrays <- length(ces)
+  res <- vector("list", nbrOfArrays)
   for (kk in seq_len(nbrOfArrays)) {
-    ce <- ces[[kk]];
+    ce <- ces[[kk]]
     verbose && enter(verbose, sprintf("Array #%d of %d ('%s')",
-                                            kk, nbrOfArrays, getName(ce)));
+                                            kk, nbrOfArrays, getName(ce)))
 
-    filename <- getFilename(ce);
-    pathname <- filePath(path, filename);
+    filename <- getFilename(ce)
+    pathname <- filePath(path, filename)
     if (isFile(pathname)) {
-      verbose && cat(verbose, "Already normalized. Skipping.");
-      ceN <- fromFile(ce, pathname);
+      verbose && cat(verbose, "Already normalized. Skipping.")
+      ceN <- fromFile(ce, pathname)
 
       # Carry over parameters too.  AD HOC for now. /HB 2007-01-07
       if (inherits(ce, "SnpChipEffectFile")) {
-        ceN$mergeStrands <- ce$mergeStrands;
+        ceN$mergeStrands <- ce$mergeStrands
         if (inherits(ce, "CnChipEffectFile")) {
-          ceN$combineAlleles <- ce$combineAlleles;
+          ceN$combineAlleles <- ce$combineAlleles
         }
       }
 
       # CDF inheritance
-      setCdf(ceN, cdf);
+      setCdf(ceN, cdf)
 
-      res[[kk]] <- ceN;
-      verbose && exit(verbose);
-      next;
+      res[[kk]] <- ceN
+      verbose && exit(verbose)
+      next
     }
 
     # Get unit-to-cell (for optimized reading)?
     if (is.null(map)) {
       # Only loaded if really needed.
-      verbose && enter(verbose, "Retrieving unit-to-cell map for all arrays");
-      map <- getUnitGroupCellMap(ce, units=subsetToUpdate, verbose=less(verbose));
-      verbose && str(verbose, map);
-      verbose && exit(verbose);
+      verbose && enter(verbose, "Retrieving unit-to-cell map for all arrays")
+      map <- getUnitGroupCellMap(ce, units=subsetToUpdate, verbose=less(verbose))
+      verbose && str(verbose, map)
+      verbose && exit(verbose)
     }
 
     if (is.null(gcContents)) {
       # Get PCR fragment lengths for the subset to be fitted
-      gcContents <- getGcContent(this, units=map[,"unit"], verbose=less(verbose, 1));
+      gcContents <- getGcContent(this, units=map[,"unit"], verbose=less(verbose, 1))
 
       # Get the index in the data vector of subset to be fitted.
       # Note: match() only returns first match, which is why we do
       # it this way.
-      subset <- match(map[,"unit"], subsetToFit);
-      subset <- subset[!is.na(subset)];
-      subset <- match(subsetToFit[subset], map[,"unit"]);
+      subset <- match(map[,"unit"], subsetToFit)
+      subset <- subset[!is.na(subset)]
+      subset <- match(subsetToFit[subset], map[,"unit"])
     }
 
     if (is.null(targetFcn)) {
       # Only loaded if really needed.
       # Retrieve/calculate the target function
-      targetFcn <- getTargetFunction(this, verbose=less(verbose));
+      targetFcn <- getTargetFunction(this, verbose=less(verbose))
     }
 
     # Get target log2 signals for all SNPs to be updated
-    verbose && enter(verbose, "Getting signals");
-    data <- getDataFlat(ce, units=map, fields="theta", verbose=less(verbose));
-    verbose && exit(verbose);
+    verbose && enter(verbose, "Getting signals")
+    data <- getDataFlat(ce, units=map, fields="theta", verbose=less(verbose))
+    verbose && exit(verbose)
 
 
     # Extract the values to fit the normalization function
-    verbose && enter(verbose, "Normalizing log2 signals");
-    y <- log2(data[,"theta"]);
+    verbose && enter(verbose, "Normalizing log2 signals")
+    y <- log2(data[,"theta"])
     y <- .normalizeFragmentLength(y, fragmentLengths=gcContents,
-                             targetFcn=targetFcn, subsetToFit=subset, ...);
-    y <- 2^y;
-    verbose && exit(verbose);
+                             targetFcn=targetFcn, subsetToFit=subset, ...)
+    y <- 2^y
+    verbose && exit(verbose)
 
     # Create CEL file to store results, if missing
-    verbose && enter(verbose, "Creating CEL file for results, if missing");
-    ceN <- createFrom(ce, filename=pathname, path=NULL, verbose=less(verbose));
-    verbose && exit(verbose);
+    verbose && enter(verbose, "Creating CEL file for results, if missing")
+    ceN <- createFrom(ce, filename=pathname, path=NULL, verbose=less(verbose))
+    verbose && exit(verbose)
 
     # Carry over parameters too.  AD HOC for now. /HB 2007-01-07
     if (inherits(ce, "SnpChipEffectFile")) {
-      ceN$mergeStrands <- ce$mergeStrands;
+      ceN$mergeStrands <- ce$mergeStrands
       if (inherits(ce, "CnChipEffectFile")) {
-        ceN$combineAlleles <- ce$combineAlleles;
+        ceN$combineAlleles <- ce$combineAlleles
       }
     }
 
     # CDF inheritance
-    setCdf(ceN, cdf);
+    setCdf(ceN, cdf)
 
-    verbose && enter(verbose, "Storing normalized signals");
-    data[,"theta"] <- y;
+    verbose && enter(verbose, "Storing normalized signals")
+    data[,"theta"] <- y
     # Not needed anymore
-    y <- NULL;
-    updateDataFlat(ceN, data=data, verbose=less(verbose));
+    y <- NULL
+    updateDataFlat(ceN, data=data, verbose=less(verbose))
     # Not needed anymore
-    data <- NULL;
+    data <- NULL
 
     ## Create checksum file
     ceNZ <- getChecksumFile(ceN)
 
-    verbose && exit(verbose);
+    verbose && exit(verbose)
 
     # Garbage collect
-    gc <- gc();
-    verbose && print(verbose, gc);
+    gc <- gc()
+    verbose && print(verbose, gc)
 
-    res[[kk]] <- ceN;
+    res[[kk]] <- ceN
 
-    verbose && exit(verbose);
+    verbose && exit(verbose)
   } # for (kk in ...)
 
   # Create the output set (ad hoc for now so that we keep parameter too)
-  outputSet <- clone(ces);
-  outputSet$files <- res;
-  clearCache(outputSet);
+  outputSet <- clone(ces)
+  outputSet$files <- res
+  clearCache(outputSet)
 
   # Update the output data set
-  this$outputSet <- outputSet;
+  this$outputSet <- outputSet
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
-  outputSet;
+  outputSet
 })
-
-############################################################################
-# HISTORY:
-# 2012-11-29
-# o getOutputDataSet00() for GcContentNormalization called the global
-#   'verbose'.
-# 2009-03-22
-# o Updated to work with AromaUgcFile:s as well.
-# o Added protected getGcContent() method.
-# 2008-02-21
-# o Now getSubsetToFit() and process() not only processes SNPs but also
-#   CN probes.
-# 2007-04-02
-# o Created from FragmentLengthNormalization.R.
-############################################################################
