@@ -9,7 +9,7 @@ library("R.utils");
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 verbose && enter(verbose, "Installing test-specific packages");
 
-pkgs <- c("BioC:limma");
+pkgs <- c("BioC:limma", "gsmoothr");
 for (pkg in pkgs) {
   verbose && cat(verbose, "Package: ", pkg);
   installPkg(pkg);
